@@ -1,6 +1,6 @@
 package Test::Lite;
 
-$Test::Lite::VERSION = '0.008';
+$Test::Lite::VERSION = '0.009';
 $Test::Lite::DieOnSyntaxError = 0;
 
 =head1 NAME
@@ -39,8 +39,7 @@ use warnings;
 
 use 5.010;
 use Scalar::Util 'looks_like_number';
-use Goose qw/:Antlers/;
-
+use Sub::Mage ':Class';
 extends 'Test::Builder::Module';
 
 my $CLASS = __PACKAGE__;
